# B0 Models

## B0DualEcho

::: qmrpy.models.b0.B0DualEcho
    options:
      members:
        - __init__
        - fit
        - fit_image
        - forward

## B0MultiEcho

::: qmrpy.models.b0.B0MultiEcho
    options:
      members:
        - __init__
        - fit
        - fit_image
